@@ -128,9 +128,7 @@ class CloudPods:
             bios="BIOS"
         else:
             bios="UEFI"
-        nets=[]
-        for net in nets_list:
-            nets.append({"network": net})
+        nets=[{"network": net} for net in nets_list.split(",")]
         server = {
             "auto_start": True,
             "generate_name": vm_name,
